@@ -1,9 +1,9 @@
-# @(#)Ident: UpdatingContent.pm 2013-05-02 18:26 pjf ;
+# @(#)Ident: UpdatingContent.pm 2013-05-04 00:01 pjf ;
 
 package Module::Provision::TraitFor::UpdatingContent;
 
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 5 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moose::Role;
 use Class::Usul::Constants;
@@ -110,7 +110,7 @@ Module::Provision::TraitFor::UpdatingContent - Perform search and replace on pro
 
 =head1 Version
 
-This documents version v0.9.$Rev: 5 $ of L<Module::Provision::TraitFor::UpdatingContent>
+This documents version v0.10.$Rev: 1 $ of L<Module::Provision::TraitFor::UpdatingContent>
 
 =head1 Description
 
@@ -121,11 +121,7 @@ Perform search and replace on project file content
 Requires the following attributes to be defined in the consuming
 class; C<appldir>
 
-Defines the following attributes;
-
-=over 3
-
-=back
+Defines no attributes
 
 =head1 Subroutines/Methods
 
